@@ -101,6 +101,7 @@ class Variable:
             if self.values:
                 self.values[0].close() # might be a long value
                 self.values[0] = val
+                self._index += 1
             else:
                 self.values.append(val)
         else:
@@ -110,7 +111,7 @@ class Variable:
         cState.writeStatus('0000')
         if _DEBUG: log.msg('setVar finished')
 
-    def getVar(self, cState, removeP, blockP, iterateP, varId='', valIndex=0):
+    def getVar(self, cState, removeP, blockP, iterateP, varId='', valIndex=-999):
         n = len(self.values)
 
         if iterateP:
@@ -425,7 +426,7 @@ class NwsService(internet.TCPServer):
             var.purge()
             cState.writeStatus('0000')
 
-    def getVar(self, cState, op, wsName, varName, varId='', valIndex=0):
+    def getVar(self, cState, op, wsName, varName, varId='', valIndex='-999'):
         if _DEBUG: log.msg('getVar (%s) called on behalf of %s' % (op, str(cState)))
         try:    bindings = self.spaces[cState.wsMap[wsName]].bindings
         except:
